# midiTeach
Chords teaching via midi  


Small app that can be connected to a midi keyboard in order to train chords.
Still in progress.

https://user-images.githubusercontent.com/6841652/121781129-ac8d9600-cba3-11eb-81fc-53b41ed7ce51.mp4
